@@ -35,7 +35,7 @@
 
 
 /*
- * $Id: machine.h,v 1.7 2010/07/29 16:03:06 abe Exp $
+ * $Id: machine.h,v 1.10 2013/01/02 17:03:05 abe Exp $
  */
 
 
@@ -46,6 +46,10 @@
 #include <sys/types.h>
 #include <sys/param.h>
 
+# if	defined(NEEDS_MACH_PORT_T)
+# include <device/device_types.h>
+# endif	/* NEED_MACH_PORT_T */
+
 #include "/usr/include/string.h"
 
 
@@ -229,12 +233,15 @@
  * private lfile elements are used.
  */
 
-#define	HASLFILEADD char *V_path;
+#define	HASLFILEADD char *V_path; \
+		    mach_port_t fileport;
 #define CLRLFILEADD(lf)	if (lf->V_path) { \
 			    (void) free((FREE_P *)lf->V_path); \
 			    lf->V_path = (char *)NULL; \
-			}
-#define SETLFILEADD Lf->V_path = (char *)NULL;
+			} \
+			lf->fileport = MACH_PORT_NULL;
+#define SETLFILEADD Lf->V_path = (char *)NULL; \
+		    Lf->fileport = MACH_PORT_NULL;
 
 
 /*
@@ -327,7 +334,7 @@
 
 /* #define	HASPRINTDEV	print_dev	*/
 /* #define	HASPRINTINO	print_ino?	*/
-/* #define	HASPRINTNM	print_nm?	*/
+#define	HASPRINTNM	print_nm
 /* #define	HASPRINTOFF	print_off?	*/
 /* #define	HASPRINTSZ	print_sz?	*/
 
