@@ -31,7 +31,7 @@
 
 
 /*
- * $Id: dlsof.h,v 1.43 2010/01/18 19:03:01 abe Exp $
+ * $Id: dlsof.h,v 1.45 2013/01/02 17:01:43 abe Exp $
  */
 
 
@@ -78,12 +78,25 @@
 #define	vm_memattr_t	void
 #  endif	/* defined(HAS_VM_MEMATTR_T) */
 
+#  if	defined(NEEDS_BOOLEAN_T)
+/*
+ * In FreeBSD 9 and above the boolean_t typedef is also needed and is also
+ * under _KERNEL in <sys/types.h>.
+ */
+
+#define	boolean_t	int
+#  endif	/* defined(NEEDS_BOOLEAN_T) */
+
 #include <sys/conf.h>
 
 #  if	defined(HAS_VM_MEMATTR_T)
 #undef	vm_memattr_t
 #  endif	/* defined(HAS_VM_MEMATTR_T) */
 
+#  if	defined(NEEDS_BOOLEAN_T)
+#undef	boolean_t
+#  endif	/* defined(NEEDS_BOOLEAN_T) */
+
 #  if	defined(HAS_CONF_MINOR)
 #undef	minor
 #include "fbsd_minor.h"
@@ -106,6 +119,15 @@
 #include <sys/mount.h>
 
 # if	FREEBSDV>=3020
+#  if	defined(__clang__)
+/*
+ * This definition is needed when clang is used, because <sys/mount.h> must
+ * be #include'd when _KERNEL is defined and that causes the getmntinfo()
+ * function prototype to be skipped.
+ */
+int     getmntinfo(struct statfs **, int);
+#  endif	/* defined(__clang__) */
+
 #undef	_KERNEL
 # endif	/* FREEBSDV>=3020 */
 
@@ -174,7 +196,24 @@ struct vop_setextattr_args;
 #include <ufs/ufs/extattr.h>
 #define	psignal	LSOF_psignal
 #define	panicstr bp
+
+#  if	defined(__clang__)
+/*
+ * Two clang work-arounds...
+ */
+#define	KASSERT(exp,msg) do {} while (0)
+#include <arpa/inet.h>
+#  endif	/* defined(__clang__) */
+
 #include <ufs/ufs/ufsmount.h>
+
+#  if	defined(__clang__)
+/*
+ * Undo the clang work-arounds.
+ */
+#undef	KASSERT
+#  endif	/* defined(__clang__) */
+
 #undef	psignal
 #undef	panicstr
 #undef	_KERNEL
@@ -315,6 +354,15 @@ struct vop_generic_args;
  * versions where testing was not possible.
  */
 
+#  if	defined(__clang__)
+/*
+ * This work-around is needed when using clang, because <sys/fcntl.h> must
+ * be #include'd under KERNEL and that causes the open() function prototype
+ * definition to be skipped.
+ */
+int     open(const char *, int, ...);
+#  endif	/* defined(__clang__) */
+
 #define	intrmask_t	int
 #define	log	log_kernel_lsof
 #define	pause	pause_kernel_lsof
