@@ -32,7 +32,7 @@
 #ifndef lint
 static char copyright[] =
 "@(#) Copyright 1994 Purdue Research Foundation.\nAll rights reserved.\n";
-static char *rcsid = "$Id: dnode.c,v 1.40 2009/03/25 19:23:06 abe Exp $";
+static char *rcsid = "$Id: dnode.c,v 1.42 2013/01/02 17:01:43 abe Exp $";
 #endif
 
 
@@ -547,6 +547,10 @@ process_overlaid_node:
 		vtag = VT_DEVFS;
 	    else if (!strcmp(vtbuf, "nfs"))
 		vtag = VT_NFS;
+	    else if (!strcmp(vtbuf, "newnfs"))
+		vtag = VT_NFS;
+	    else if (!strcmp(vtbuf, "oldnfs"))
+		vtag = VT_NFS;
 	    else if (!strcmp(vtbuf, "isofs"))
 		vtag = VT_ISOFS;
 	    else if (!strcmp(vtbuf, "pseudofs"))
@@ -780,7 +784,9 @@ process_overlaid_node:
 #if	defined(HAS_ZFS)
 	case VT_ZFS:
 	    if (!v->v_data
-	    ||  (zm = readzfsnode((KA_T)v->v_data, &zi))) {
+	    ||  (zm = readzfsnode((KA_T)v->v_data, &zi,
+				  ((v->v_vflag & VV_ROOT) ? 1 : 0)))
+	    ) {
 		(void) snpf(Namech, Namechl, "%s: %s", zm,
 		    print_kptr((KA_T)v->v_data, (char *)NULL, 0));
 		enter_nm(Namech);
@@ -949,7 +955,7 @@ process_overlaid_node:
 		dev = DevDev;
 		devs = 1;
 	    }
-	    if ((type == VCHR)) {
+	    if (type == VCHR) {
 
 # if	defined(HAS_UFS1_2)
 		if (ufst == 1) {
