@@ -32,7 +32,7 @@
 #ifndef lint
 static char copyright[] =
 "@(#) Copyright 1994 Purdue Research Foundation.\nAll rights reserved.\n";
-static char *rcsid = "$Id: dproc.c,v 1.16 2008/10/21 16:16:06 abe Exp $";
+static char *rcsid = "$Id: dproc.c,v 1.17 2013/01/02 17:01:43 abe Exp $";
 #endif
 
 #include "lsof.h"
@@ -126,6 +126,7 @@ gather_proc_info()
 	int ppid = 0;
 	short pss, sf;
 	int px;
+	int tid;			/* thread (task) ID */
 	uid_t uid;
 
 #if	FREEBSDV<2000
@@ -197,7 +198,14 @@ gather_proc_info()
 #if	FREEBSDV<2000
 	if ((Np = kvm_getprocs(KINFO_PROC_ALL, 0)) < 0)
 #else	/* FREEBSDV>=2000 */
-	if ((P = kvm_getprocs(Kd, KERN_PROC_ALL, 0, &Np)) == NULL)
+
+# if	!defined(KERN_PROC_PROC)
+#define	KERN_PROC_PROC  KERN_PROC_ALL
+# endif	/* !defined(KERN_PROC_PROC) */
+
+	if ((P = kvm_getprocs(Kd, Ftask ? KERN_PROC_ALL : KERN_PROC_PROC,
+			      0, &Np))
+	== NULL)
 #endif	/* FREEBSDV<2000 */
 
 	{
@@ -259,13 +267,24 @@ gather_proc_info()
 	    ppid = p->P_PPID;
 #endif	/* defined(HASPPID) */
 
+#if	defined(HASTASKS)
+	/*
+	 * See if process,including its tasks, is excluded.
+	 */
+	    tid = Ftask ? (int)p->ki_tid : 0;
+	    if (is_proc_excl(p->P_PID, pgid, (UID_ARG)uid, &pss, &sf, tid))
+		continue;
+#else	/* !defined(HASTASKS) */
 	/*
 	 * See if process is excluded.
-	 *
-	 * Read file structure pointers.
 	 */
 	    if (is_proc_excl(p->P_PID, pgid, (UID_ARG)uid, &pss, &sf))
 		continue;
+#endif	/* defined(HASTASKS) */
+
+	/*
+	 * Read file structure pointers.
+	 */
 	    if (!p->P_FD
 	    ||  kread((KA_T)p->P_FD, (char *)&fd, sizeof(fd)))
 		continue;
@@ -289,6 +308,13 @@ gather_proc_info()
 		(int)pss, (int)sf);
 	    Plf = (struct lfile *)NULL;
 
+#if	defined(HASTASKS)
+	/*
+	 * Save the task (thread) ID.
+	 */
+	    Lp->tid = tid;
+#endif	/* defined(HASTASKS) */
+
 #if	defined(P_ADDR)
 	/*
 	 * Save the kernel proc struct address, if P_ADDR is defined.
@@ -395,10 +421,12 @@ gather_proc_info()
 		}
 	    }
 	/*
-	 * Examine results.
+	 * Unless threads (tasks) are being processed, examine results.
 	 */
-	    if (examine_lproc())
-		return;
+	    if (!Ftask) {
+		if (examine_lproc())
+		    return;
+	    }
 	}
 }
 
@@ -524,7 +552,7 @@ get_nlist_path(ap)
 	    if (!(bfc = (char *)malloc(bfl))) {
 		(void) fprintf(stderr,
 		    "%s: can't allocate %d bytes for boot file path: %s\n",
-		    Pn, bfl, bf);
+		    Pn, (int)bfl, bf);
 		Exit(1);
 	    }
 	    (void) snpf(bfc, bfl, "%s", bf);
